==> ui-framework-4.5.4-sources.jar: io/intino/alexandria/ui/displays/items/Grouping1Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class Grouping1Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName1 firstName1;
	public Gro_17_7_01633428737 gro_17_7_01633428737;
	public Grouping1Mold.Gro_17_7_01633428737. Gender1 gender1;
	public Grouping1Mold.Gro_17_7_01633428737. Age1 age1;

    public Grouping1Mold(UiFrameworkBox box) {
        super(box);
        id("a_1176726209");
    }

    @Override
	public void init() {
		super.init();
		if (firstName1 == null) firstName1 = register(new FirstName1(box()).<FirstName1>id("a1156355382").owner(Grouping1Mold.this));
		if (gro_17_7_01633428737 == null) gro_17_7_01633428737 = register(new Gro_17_7_01633428737(box()).<Gro_17_7_01633428737>id("a_950673552").owner(Grouping1Mold.this));
		if (gro_17_7_01633428737 != null) gender1 = gro_17_7_01633428737.gender1;
		if (gro_17_7_01633428737 != null) age1 = gro_17_7_01633428737.age1;
	}

	public class FirstName1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName1(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class Gro_17_7_01633428737 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public Grouping1Mold.Gro_17_7_01633428737. Gender1 gender1;
		public Grouping1Mold.Gro_17_7_01633428737. Age1 age1;

		public Gro_17_7_01633428737(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender1 == null) gender1 = register(new Gender1(box()).<Gender1>id("a_164460469").owner(Grouping1Mold.this));
			if (age1 == null) age1 = register(new Age1(box()).<Age1>id("a_1993476553").owner(Grouping1Mold.this));
		}

		public class Gender1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender1(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age1(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> ui-framework-4.14.2-sources.jar: io/intino/alexandria/ui/displays/items/Grouping1Mold.java <==
package io.intino.alexandria.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class Grouping1Mold extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, io.intino.alexandria.ui.documentation.Person, UiFrameworkBox> {
	public FirstName1 firstName1;
	public _17_7_01633428737 _17_7_01633428737;
	public Grouping1Mold._17_7_01633428737. Gender1 gender1;
	public Grouping1Mold._17_7_01633428737. Age1 age1;

    public Grouping1Mold(UiFrameworkBox box) {
        super(box);
        id("a_1176726209");
    }

    @Override
	public void init() {
		super.init();
		if (firstName1 == null) firstName1 = register(new FirstName1(box()).<FirstName1>id("a1156355382").owner(Grouping1Mold.this));
		if (_17_7_01633428737 == null) _17_7_01633428737 = register(new _17_7_01633428737(box()).<_17_7_01633428737>id("a335267284").owner(Grouping1Mold.this));
		if (_17_7_01633428737 != null) gender1 = _17_7_01633428737.gender1;
		if (_17_7_01633428737 != null) age1 = _17_7_01633428737.age1;
	}

	public class FirstName1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

		public FirstName1(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _17_7_01633428737 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UiFrameworkBox>  {
		public Grouping1Mold._17_7_01633428737. Gender1 gender1;
		public Grouping1Mold._17_7_01633428737. Age1 age1;

		public _17_7_01633428737(UiFrameworkBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (gender1 == null) gender1 = register(new Gender1(box()).<Gender1>id("a_164460469").owner(Grouping1Mold.this));
			if (age1 == null) age1 = register(new Age1(box()).<Age1>id("a_1993476553").owner(Grouping1Mold.this));
		}

		public class Gender1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Gender1(UiFrameworkBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Age1 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UiFrameworkBox>  {

			public Age1(UiFrameworkBox box) {
				super(box);
				label("age");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}
